@@ -1,9 +1,13 @@
-NUM_VERSION = (2013, 5, 1)
+NUM_VERSION = (2015, 1)
 VERSION = ".".join(str(nv) for nv in NUM_VERSION)
 __version__ = VERSION
 
 from pudb.py3compat import raw_input, PY3
 
+from pudb.settings import load_config, save_config
+CONFIG = load_config()
+save_config(CONFIG)
+
 
 class PudbShortcuts(object):
     @property
@@ -83,6 +87,9 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False):
             import urwid
             pre_run_edit = urwid.Edit("", pre_run)
 
+            if not CONFIG["prompt_on_quit"]:
+                return
+
             result = dbg.ui.call_with_ui(dbg.ui.dialog,
                 urwid.ListBox(urwid.SimpleListWalker([urwid.Text(
                     "Your PuDB session has ended.\n\n%s"
